===========
logtailor
===========


.. image:: https://img.shields.io/pypi/v/logtailor.svg
        :target: https://pypi.python.org/pypi/logtailor

.. image:: https://img.shields.io/travis/stbraun/logtailor.svg
        :target: https://travis-ci.org/stbraun/logtailor

.. image:: https://readthedocs.org/projects/logtailor/badge/?version=latest
        :target: https://logtailor.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A tool to tail and filter log files of running applications.


* Free software: MIT license
* Documentation: https://logtailor.readthedocs.io.


Features
--------

* Filter a logfile by multiple filter criteria.
* Tail and filter the logfile of a running application.
* Tail and filter multiple logfiles of running applications simultanuously.

Credits
-------

This package was created with Cookiecutter_ and the `stbraun/cookiecutter-pypackage`_ project template based on `audreyr/cookiecutter-pypackage`.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`stbraun/cookiecutter-pypackage`: https://github.com/stbraun/cookiecutter-pypackage.git
